Index: /Scheduling/trunk/cs/bsdx0200GUISourceCode/CGAVView.cs
===================================================================
--- /Scheduling/trunk/cs/bsdx0200GUISourceCode/CGAVView.cs	(revision 907)
+++ /Scheduling/trunk/cs/bsdx0200GUISourceCode/CGAVView.cs	(revision 908)
@@ -867,4 +867,12 @@
             this.mnu7Day.Click += new System.EventHandler(this.dateTimePicker1_ValueChanged);
 
+            //Set start date
+            DateTime startDate,endDate;
+            Document.WeekNeedsRefresh(1, DateTime.Today, out startDate, out endDate);
+            this.StartDate = startDate;
+            //Draw the calendar
+            this.calendarGrid1.OnUpdateArrays();
+            this.calendarGrid1.Invalidate();
+
 		}
 
Index: /Scheduling/trunk/cs/bsdx0200GUISourceCode/ClinicalScheduling.csproj
===================================================================
--- /Scheduling/trunk/cs/bsdx0200GUISourceCode/ClinicalScheduling.csproj	(revision 907)
+++ /Scheduling/trunk/cs/bsdx0200GUISourceCode/ClinicalScheduling.csproj	(revision 908)
@@ -67,5 +67,5 @@
     <ConfigurationOverrideFile>
     </ConfigurationOverrideFile>
-    <DefineConstants>DEBUG</DefineConstants>
+    <DefineConstants>TRACE;DEBUG</DefineConstants>
     <DocumentationFile>bin\Release\ClinicalScheduling.XML</DocumentationFile>
     <DebugSymbols>false</DebugSymbols>
@@ -90,6 +90,5 @@
     <ConfigurationOverrideFile>
     </ConfigurationOverrideFile>
-    <DefineConstants>
-    </DefineConstants>
+    <DefineConstants>TRACE</DefineConstants>
     <DocumentationFile>bin\Release\ClinicalScheduling.XML</DocumentationFile>
     <DebugSymbols>false</DebugSymbols>
Index: /Scheduling/trunk/cs/bsdx0200GUISourceCode/ClinicalScheduling.csproj.user
===================================================================
--- /Scheduling/trunk/cs/bsdx0200GUISourceCode/ClinicalScheduling.csproj.user	(revision 907)
+++ /Scheduling/trunk/cs/bsdx0200GUISourceCode/ClinicalScheduling.csproj.user	(revision 908)
@@ -36,5 +36,5 @@
     </RemoteDebugMachine>
     <StartAction>Project</StartAction>
-    <StartArguments>/s=10.161.20.25 /p=9235 /a=shabiel12 /v=abc,123! /e=windows-1256</StartArguments>
+    <StartArguments>/s=172.16.16.125 /p=9250 /a=shabiel12 /v=abc,123! /e=utf-8</StartArguments>
     <StartPage>
     </StartPage>
@@ -55,5 +55,5 @@
     </RemoteDebugMachine>
     <StartAction>Project</StartAction>
-    <StartArguments>/s=10.161.20.25 /p=9235 /a=shabiel12 /v=abc,123! /e=windows-1256</StartArguments>
+    <StartArguments>/s=172.16.16.125 /p=9250 /a=shabiel12 /v=abc,123! /e=utf-8</StartArguments>
     <StartPage>
     </StartPage>
Index: /Scheduling/trunk/cs/bsdx0200GUISourceCode/DApptSearch.cs
===================================================================
--- /Scheduling/trunk/cs/bsdx0200GUISourceCode/DApptSearch.cs	(revision 907)
+++ /Scheduling/trunk/cs/bsdx0200GUISourceCode/DApptSearch.cs	(revision 908)
@@ -268,338 +268,338 @@
 		private void InitializeComponent()
 		{
-			this.panel1 = new System.Windows.Forms.Panel();
-			this.cmdSearch = new System.Windows.Forms.Button();
-			this.cmdCancel = new System.Windows.Forms.Button();
-			this.cmdOK = new System.Windows.Forms.Button();
-			this.pnlDescription = new System.Windows.Forms.Panel();
-			this.grpDescription = new System.Windows.Forms.GroupBox();
-			this.lblDescription = new System.Windows.Forms.Label();
-			this.groupBox1 = new System.Windows.Forms.GroupBox();
-			this.label3 = new System.Windows.Forms.Label();
-			this.label2 = new System.Windows.Forms.Label();
-			this.lstAccessTypes = new System.Windows.Forms.CheckedListBox();
-			this.cboAccessTypeFilter = new System.Windows.Forms.ComboBox();
-			this.grpDayOfWeek = new System.Windows.Forms.GroupBox();
-			this.chkSun = new System.Windows.Forms.CheckBox();
-			this.chkSat = new System.Windows.Forms.CheckBox();
-			this.chkFri = new System.Windows.Forms.CheckBox();
-			this.chkThu = new System.Windows.Forms.CheckBox();
-			this.chkWed = new System.Windows.Forms.CheckBox();
-			this.chkTue = new System.Windows.Forms.CheckBox();
-			this.chkMon = new System.Windows.Forms.CheckBox();
-			this.grpTimeOfDay = new System.Windows.Forms.GroupBox();
-			this.rdoBoth = new System.Windows.Forms.RadioButton();
-			this.rdoPM = new System.Windows.Forms.RadioButton();
-			this.rdoAM = new System.Windows.Forms.RadioButton();
-			this.label1 = new System.Windows.Forms.Label();
-			this.calStartDate = new System.Windows.Forms.MonthCalendar();
-			this.groupBox2 = new System.Windows.Forms.GroupBox();
-			this.grdResult = new System.Windows.Forms.DataGrid();
-			this.panel1.SuspendLayout();
-			this.pnlDescription.SuspendLayout();
-			this.grpDescription.SuspendLayout();
-			this.groupBox1.SuspendLayout();
-			this.grpDayOfWeek.SuspendLayout();
-			this.grpTimeOfDay.SuspendLayout();
-			this.groupBox2.SuspendLayout();
-			((System.ComponentModel.ISupportInitialize)(this.grdResult)).BeginInit();
-			this.SuspendLayout();
-			// 
-			// panel1
-			// 
-			this.panel1.Controls.Add(this.cmdSearch);
-			this.panel1.Controls.Add(this.cmdCancel);
-			this.panel1.Controls.Add(this.cmdOK);
-			this.panel1.Dock = System.Windows.Forms.DockStyle.Bottom;
-			this.panel1.Location = new System.Drawing.Point(0, 456);
-			this.panel1.Name = "panel1";
-			this.panel1.Size = new System.Drawing.Size(730, 40);
-			this.panel1.TabIndex = 4;
-			// 
-			// cmdSearch
-			// 
-			this.cmdSearch.Location = new System.Drawing.Point(536, 8);
-			this.cmdSearch.Name = "cmdSearch";
-			this.cmdSearch.Size = new System.Drawing.Size(72, 24);
-			this.cmdSearch.TabIndex = 2;
-			this.cmdSearch.Text = "Search";
-			this.cmdSearch.Click += new System.EventHandler(this.cmdSearch_Click);
-			// 
-			// cmdCancel
-			// 
-			this.cmdCancel.DialogResult = System.Windows.Forms.DialogResult.Cancel;
-			this.cmdCancel.Location = new System.Drawing.Point(616, 8);
-			this.cmdCancel.Name = "cmdCancel";
-			this.cmdCancel.Size = new System.Drawing.Size(64, 24);
-			this.cmdCancel.TabIndex = 1;
-			this.cmdCancel.Text = "Cancel";
-			// 
-			// cmdOK
-			// 
-			this.cmdOK.DialogResult = System.Windows.Forms.DialogResult.OK;
-			this.cmdOK.Location = new System.Drawing.Point(128, 8);
-			this.cmdOK.Name = "cmdOK";
-			this.cmdOK.Size = new System.Drawing.Size(64, 24);
-			this.cmdOK.TabIndex = 0;
-			this.cmdOK.Text = "OK";
-			this.cmdOK.Visible = false;
-			this.cmdOK.Click += new System.EventHandler(this.cmdOK_Click);
-			// 
-			// pnlDescription
-			// 
-			this.pnlDescription.Controls.Add(this.grpDescription);
-			this.pnlDescription.Dock = System.Windows.Forms.DockStyle.Bottom;
-			this.pnlDescription.Location = new System.Drawing.Point(0, 392);
-			this.pnlDescription.Name = "pnlDescription";
-			this.pnlDescription.Size = new System.Drawing.Size(730, 64);
-			this.pnlDescription.TabIndex = 47;
-			// 
-			// grpDescription
-			// 
-			this.grpDescription.Controls.Add(this.lblDescription);
-			this.grpDescription.Dock = System.Windows.Forms.DockStyle.Fill;
-			this.grpDescription.Location = new System.Drawing.Point(0, 0);
-			this.grpDescription.Name = "grpDescription";
-			this.grpDescription.Size = new System.Drawing.Size(730, 64);
-			this.grpDescription.TabIndex = 0;
-			this.grpDescription.TabStop = false;
-			this.grpDescription.Text = "Description";
-			// 
-			// lblDescription
-			// 
-			this.lblDescription.Dock = System.Windows.Forms.DockStyle.Fill;
-			this.lblDescription.Location = new System.Drawing.Point(3, 16);
-			this.lblDescription.Name = "lblDescription";
-			this.lblDescription.Size = new System.Drawing.Size(724, 45);
-			this.lblDescription.TabIndex = 1;
-			this.lblDescription.Text = "Search for available appointment times using this panel.  You may narrow your sea" +
-				"rch by selecting an access type or by selecting specific days of the week or tim" +
-				"es of day.";
-			// 
-			// groupBox1
-			// 
-			this.groupBox1.Controls.Add(this.label3);
-			this.groupBox1.Controls.Add(this.label2);
-			this.groupBox1.Controls.Add(this.lstAccessTypes);
-			this.groupBox1.Controls.Add(this.cboAccessTypeFilter);
-			this.groupBox1.Controls.Add(this.grpDayOfWeek);
-			this.groupBox1.Controls.Add(this.grpTimeOfDay);
-			this.groupBox1.Controls.Add(this.label1);
-			this.groupBox1.Controls.Add(this.calStartDate);
-			this.groupBox1.Dock = System.Windows.Forms.DockStyle.Top;
-			this.groupBox1.Location = new System.Drawing.Point(0, 0);
-			this.groupBox1.Name = "groupBox1";
-			this.groupBox1.Size = new System.Drawing.Size(730, 208);
-			this.groupBox1.TabIndex = 56;
-			this.groupBox1.TabStop = false;
-			this.groupBox1.Text = "Search Parameters";
-			// 
-			// label3
-			// 
-			this.label3.Location = new System.Drawing.Point(472, 72);
-			this.label3.Name = "label3";
-			this.label3.Size = new System.Drawing.Size(80, 16);
-			this.label3.TabIndex = 63;
-			this.label3.Text = "Access Type:";
-			// 
-			// label2
-			// 
-			this.label2.Location = new System.Drawing.Point(472, 24);
-			this.label2.Name = "label2";
-			this.label2.Size = new System.Drawing.Size(104, 16);
-			this.label2.TabIndex = 62;
-			this.label2.Text = "Access Group:";
-			// 
-			// lstAccessTypes
-			// 
-			this.lstAccessTypes.CheckOnClick = true;
-			this.lstAccessTypes.HorizontalScrollbar = true;
-			this.lstAccessTypes.Location = new System.Drawing.Point(472, 88);
-			this.lstAccessTypes.MultiColumn = true;
-			this.lstAccessTypes.Name = "lstAccessTypes";
-			this.lstAccessTypes.Size = new System.Drawing.Size(224, 109);
-			this.lstAccessTypes.TabIndex = 61;
-			// 
-			// cboAccessTypeFilter
-			// 
-			this.cboAccessTypeFilter.Location = new System.Drawing.Point(472, 40);
-			this.cboAccessTypeFilter.Name = "cboAccessTypeFilter";
-			this.cboAccessTypeFilter.Size = new System.Drawing.Size(224, 21);
-			this.cboAccessTypeFilter.TabIndex = 60;
-			this.cboAccessTypeFilter.Text = "cboAccessTypeFilter";
-			this.cboAccessTypeFilter.SelectionChangeCommitted += new System.EventHandler(this.cboAccessTypeFilter_SelectionChangeCommitted);
-			// 
-			// grpDayOfWeek
-			// 
-			this.grpDayOfWeek.Controls.Add(this.chkSun);
-			this.grpDayOfWeek.Controls.Add(this.chkSat);
-			this.grpDayOfWeek.Controls.Add(this.chkFri);
-			this.grpDayOfWeek.Controls.Add(this.chkThu);
-			this.grpDayOfWeek.Controls.Add(this.chkWed);
-			this.grpDayOfWeek.Controls.Add(this.chkTue);
-			this.grpDayOfWeek.Controls.Add(this.chkMon);
-			this.grpDayOfWeek.Location = new System.Drawing.Point(224, 96);
-			this.grpDayOfWeek.Name = "grpDayOfWeek";
-			this.grpDayOfWeek.Size = new System.Drawing.Size(240, 96);
-			this.grpDayOfWeek.TabIndex = 59;
-			this.grpDayOfWeek.TabStop = false;
-			this.grpDayOfWeek.Text = "Day of the Week";
-			// 
-			// chkSun
-			// 
-			this.chkSun.Location = new System.Drawing.Point(176, 64);
-			this.chkSun.Name = "chkSun";
-			this.chkSun.Size = new System.Drawing.Size(48, 16);
-			this.chkSun.TabIndex = 6;
-			this.chkSun.Text = "Sun";
-			// 
-			// chkSat
-			// 
-			this.chkSat.Location = new System.Drawing.Point(128, 64);
-			this.chkSat.Name = "chkSat";
-			this.chkSat.Size = new System.Drawing.Size(48, 16);
-			this.chkSat.TabIndex = 5;
-			this.chkSat.Text = "Sat";
-			// 
-			// chkFri
-			// 
-			this.chkFri.Location = new System.Drawing.Point(72, 64);
-			this.chkFri.Name = "chkFri";
-			this.chkFri.Size = new System.Drawing.Size(48, 16);
-			this.chkFri.TabIndex = 4;
-			this.chkFri.Text = "Fri";
-			// 
-			// chkThu
-			// 
-			this.chkThu.Location = new System.Drawing.Point(16, 64);
-			this.chkThu.Name = "chkThu";
-			this.chkThu.Size = new System.Drawing.Size(48, 16);
-			this.chkThu.TabIndex = 3;
-			this.chkThu.Text = "Thu";
-			// 
-			// chkWed
-			// 
-			this.chkWed.Location = new System.Drawing.Point(128, 32);
-			this.chkWed.Name = "chkWed";
-			this.chkWed.Size = new System.Drawing.Size(48, 16);
-			this.chkWed.TabIndex = 2;
-			this.chkWed.Text = "Wed";
-			// 
-			// chkTue
-			// 
-			this.chkTue.Location = new System.Drawing.Point(72, 32);
-			this.chkTue.Name = "chkTue";
-			this.chkTue.Size = new System.Drawing.Size(48, 16);
-			this.chkTue.TabIndex = 1;
-			this.chkTue.Text = "Tue";
-			// 
-			// chkMon
-			// 
-			this.chkMon.Location = new System.Drawing.Point(16, 32);
-			this.chkMon.Name = "chkMon";
-			this.chkMon.Size = new System.Drawing.Size(48, 16);
-			this.chkMon.TabIndex = 0;
-			this.chkMon.Text = "Mon";
-			// 
-			// grpTimeOfDay
-			// 
-			this.grpTimeOfDay.Controls.Add(this.rdoBoth);
-			this.grpTimeOfDay.Controls.Add(this.rdoPM);
-			this.grpTimeOfDay.Controls.Add(this.rdoAM);
-			this.grpTimeOfDay.Location = new System.Drawing.Point(224, 32);
-			this.grpTimeOfDay.Name = "grpTimeOfDay";
-			this.grpTimeOfDay.Size = new System.Drawing.Size(240, 48);
-			this.grpTimeOfDay.TabIndex = 58;
-			this.grpTimeOfDay.TabStop = false;
-			this.grpTimeOfDay.Text = "Time of Day";
-			// 
-			// rdoBoth
-			// 
-			this.rdoBoth.Checked = true;
-			this.rdoBoth.Location = new System.Drawing.Point(176, 24);
-			this.rdoBoth.Name = "rdoBoth";
-			this.rdoBoth.Size = new System.Drawing.Size(48, 16);
-			this.rdoBoth.TabIndex = 2;
-			this.rdoBoth.TabStop = true;
-			this.rdoBoth.Text = "Both";
-			// 
-			// rdoPM
-			// 
-			this.rdoPM.Location = new System.Drawing.Point(96, 24);
-			this.rdoPM.Name = "rdoPM";
-			this.rdoPM.Size = new System.Drawing.Size(72, 16);
-			this.rdoPM.TabIndex = 1;
-			this.rdoPM.Text = "PM Only";
-			// 
-			// rdoAM
-			// 
-			this.rdoAM.Location = new System.Drawing.Point(16, 24);
-			this.rdoAM.Name = "rdoAM";
-			this.rdoAM.Size = new System.Drawing.Size(72, 16);
-			this.rdoAM.TabIndex = 0;
-			this.rdoAM.Text = "AM Only";
-			// 
-			// label1
-			// 
-			this.label1.Font = new System.Drawing.Font("Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((System.Byte)(0)));
-			this.label1.Location = new System.Drawing.Point(16, 24);
-			this.label1.Name = "label1";
-			this.label1.Size = new System.Drawing.Size(136, 16);
-			this.label1.TabIndex = 57;
-			this.label1.Text = "Date Range:";
-			// 
-			// calStartDate
-			// 
-			this.calStartDate.Location = new System.Drawing.Point(16, 40);
-			this.calStartDate.MaxSelectionCount = 62;
-			this.calStartDate.Name = "calStartDate";
-			this.calStartDate.TabIndex = 56;
-			// 
-			// groupBox2
-			// 
-			this.groupBox2.Controls.Add(this.grdResult);
-			this.groupBox2.Dock = System.Windows.Forms.DockStyle.Fill;
-			this.groupBox2.Location = new System.Drawing.Point(0, 208);
-			this.groupBox2.Name = "groupBox2";
-			this.groupBox2.Size = new System.Drawing.Size(730, 184);
-			this.groupBox2.TabIndex = 57;
-			this.groupBox2.TabStop = false;
-			this.groupBox2.Text = "Search Result";
-			// 
-			// grdResult
-			// 
-			this.grdResult.CaptionVisible = false;
-			this.grdResult.DataMember = "";
-			this.grdResult.Dock = System.Windows.Forms.DockStyle.Fill;
-			this.grdResult.HeaderForeColor = System.Drawing.SystemColors.ControlText;
-			this.grdResult.Location = new System.Drawing.Point(3, 16);
-			this.grdResult.Name = "grdResult";
-			this.grdResult.ReadOnly = true;
-			this.grdResult.Size = new System.Drawing.Size(724, 165);
-			this.grdResult.TabIndex = 0;
-			this.grdResult.DoubleClick += new System.EventHandler(this.grdResult_DoubleClick);
-			this.grdResult.CurrentCellChanged += new System.EventHandler(this.grdResult_CurrentCellChanged);
-			// 
-			// DApptSearch
-			// 
-			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
-			this.CancelButton = this.cmdCancel;
-			this.ClientSize = new System.Drawing.Size(730, 496);
-			this.Controls.Add(this.groupBox2);
-			this.Controls.Add(this.groupBox1);
-			this.Controls.Add(this.pnlDescription);
-			this.Controls.Add(this.panel1);
-			this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedDialog;
-			this.Name = "DApptSearch";
-			this.Text = "Find Clinic Availability";
-			this.panel1.ResumeLayout(false);
-			this.pnlDescription.ResumeLayout(false);
-			this.grpDescription.ResumeLayout(false);
-			this.groupBox1.ResumeLayout(false);
-			this.grpDayOfWeek.ResumeLayout(false);
-			this.grpTimeOfDay.ResumeLayout(false);
-			this.groupBox2.ResumeLayout(false);
-			((System.ComponentModel.ISupportInitialize)(this.grdResult)).EndInit();
-			this.ResumeLayout(false);
+            this.panel1 = new System.Windows.Forms.Panel();
+            this.cmdSearch = new System.Windows.Forms.Button();
+            this.cmdCancel = new System.Windows.Forms.Button();
+            this.cmdOK = new System.Windows.Forms.Button();
+            this.pnlDescription = new System.Windows.Forms.Panel();
+            this.grpDescription = new System.Windows.Forms.GroupBox();
+            this.lblDescription = new System.Windows.Forms.Label();
+            this.groupBox1 = new System.Windows.Forms.GroupBox();
+            this.label3 = new System.Windows.Forms.Label();
+            this.label2 = new System.Windows.Forms.Label();
+            this.lstAccessTypes = new System.Windows.Forms.CheckedListBox();
+            this.cboAccessTypeFilter = new System.Windows.Forms.ComboBox();
+            this.grpDayOfWeek = new System.Windows.Forms.GroupBox();
+            this.chkSun = new System.Windows.Forms.CheckBox();
+            this.chkSat = new System.Windows.Forms.CheckBox();
+            this.chkFri = new System.Windows.Forms.CheckBox();
+            this.chkThu = new System.Windows.Forms.CheckBox();
+            this.chkWed = new System.Windows.Forms.CheckBox();
+            this.chkTue = new System.Windows.Forms.CheckBox();
+            this.chkMon = new System.Windows.Forms.CheckBox();
+            this.grpTimeOfDay = new System.Windows.Forms.GroupBox();
+            this.rdoBoth = new System.Windows.Forms.RadioButton();
+            this.rdoPM = new System.Windows.Forms.RadioButton();
+            this.rdoAM = new System.Windows.Forms.RadioButton();
+            this.label1 = new System.Windows.Forms.Label();
+            this.calStartDate = new System.Windows.Forms.MonthCalendar();
+            this.groupBox2 = new System.Windows.Forms.GroupBox();
+            this.grdResult = new System.Windows.Forms.DataGrid();
+            this.panel1.SuspendLayout();
+            this.pnlDescription.SuspendLayout();
+            this.grpDescription.SuspendLayout();
+            this.groupBox1.SuspendLayout();
+            this.grpDayOfWeek.SuspendLayout();
+            this.grpTimeOfDay.SuspendLayout();
+            this.groupBox2.SuspendLayout();
+            ((System.ComponentModel.ISupportInitialize)(this.grdResult)).BeginInit();
+            this.SuspendLayout();
+            // 
+            // panel1
+            // 
+            this.panel1.Controls.Add(this.cmdSearch);
+            this.panel1.Controls.Add(this.cmdCancel);
+            this.panel1.Controls.Add(this.cmdOK);
+            this.panel1.Dock = System.Windows.Forms.DockStyle.Bottom;
+            this.panel1.Location = new System.Drawing.Point(0, 461);
+            this.panel1.Name = "panel1";
+            this.panel1.Size = new System.Drawing.Size(923, 40);
+            this.panel1.TabIndex = 4;
+            // 
+            // cmdSearch
+            // 
+            this.cmdSearch.Location = new System.Drawing.Point(536, 8);
+            this.cmdSearch.Name = "cmdSearch";
+            this.cmdSearch.Size = new System.Drawing.Size(72, 24);
+            this.cmdSearch.TabIndex = 2;
+            this.cmdSearch.Text = "Search";
+            this.cmdSearch.Click += new System.EventHandler(this.cmdSearch_Click);
+            // 
+            // cmdCancel
+            // 
+            this.cmdCancel.DialogResult = System.Windows.Forms.DialogResult.Cancel;
+            this.cmdCancel.Location = new System.Drawing.Point(616, 8);
+            this.cmdCancel.Name = "cmdCancel";
+            this.cmdCancel.Size = new System.Drawing.Size(64, 24);
+            this.cmdCancel.TabIndex = 1;
+            this.cmdCancel.Text = "Cancel";
+            // 
+            // cmdOK
+            // 
+            this.cmdOK.DialogResult = System.Windows.Forms.DialogResult.OK;
+            this.cmdOK.Location = new System.Drawing.Point(128, 8);
+            this.cmdOK.Name = "cmdOK";
+            this.cmdOK.Size = new System.Drawing.Size(64, 24);
+            this.cmdOK.TabIndex = 0;
+            this.cmdOK.Text = "OK";
+            this.cmdOK.Visible = false;
+            this.cmdOK.Click += new System.EventHandler(this.cmdOK_Click);
+            // 
+            // pnlDescription
+            // 
+            this.pnlDescription.Controls.Add(this.grpDescription);
+            this.pnlDescription.Dock = System.Windows.Forms.DockStyle.Bottom;
+            this.pnlDescription.Location = new System.Drawing.Point(0, 397);
+            this.pnlDescription.Name = "pnlDescription";
+            this.pnlDescription.Size = new System.Drawing.Size(923, 64);
+            this.pnlDescription.TabIndex = 47;
+            // 
+            // grpDescription
+            // 
+            this.grpDescription.Controls.Add(this.lblDescription);
+            this.grpDescription.Dock = System.Windows.Forms.DockStyle.Fill;
+            this.grpDescription.Location = new System.Drawing.Point(0, 0);
+            this.grpDescription.Name = "grpDescription";
+            this.grpDescription.Size = new System.Drawing.Size(923, 64);
+            this.grpDescription.TabIndex = 0;
+            this.grpDescription.TabStop = false;
+            this.grpDescription.Text = "Description";
+            // 
+            // lblDescription
+            // 
+            this.lblDescription.Dock = System.Windows.Forms.DockStyle.Fill;
+            this.lblDescription.Location = new System.Drawing.Point(3, 16);
+            this.lblDescription.Name = "lblDescription";
+            this.lblDescription.Size = new System.Drawing.Size(917, 45);
+            this.lblDescription.TabIndex = 1;
+            this.lblDescription.Text = "Search for available appointment times using this panel.  You may narrow your sea" +
+                "rch by selecting an access type or by selecting specific days of the week or tim" +
+                "es of day.";
+            // 
+            // groupBox1
+            // 
+            this.groupBox1.Controls.Add(this.label3);
+            this.groupBox1.Controls.Add(this.label2);
+            this.groupBox1.Controls.Add(this.lstAccessTypes);
+            this.groupBox1.Controls.Add(this.cboAccessTypeFilter);
+            this.groupBox1.Controls.Add(this.grpDayOfWeek);
+            this.groupBox1.Controls.Add(this.grpTimeOfDay);
+            this.groupBox1.Controls.Add(this.label1);
+            this.groupBox1.Controls.Add(this.calStartDate);
+            this.groupBox1.Dock = System.Windows.Forms.DockStyle.Top;
+            this.groupBox1.Location = new System.Drawing.Point(0, 0);
+            this.groupBox1.Name = "groupBox1";
+            this.groupBox1.Size = new System.Drawing.Size(923, 208);
+            this.groupBox1.TabIndex = 56;
+            this.groupBox1.TabStop = false;
+            this.groupBox1.Text = "Search Parameters";
+            // 
+            // label3
+            // 
+            this.label3.Location = new System.Drawing.Point(684, 64);
+            this.label3.Name = "label3";
+            this.label3.Size = new System.Drawing.Size(80, 16);
+            this.label3.TabIndex = 63;
+            this.label3.Text = "Access Type:";
+            // 
+            // label2
+            // 
+            this.label2.Location = new System.Drawing.Point(684, 21);
+            this.label2.Name = "label2";
+            this.label2.Size = new System.Drawing.Size(104, 16);
+            this.label2.TabIndex = 62;
+            this.label2.Text = "Access Group:";
+            // 
+            // lstAccessTypes
+            // 
+            this.lstAccessTypes.CheckOnClick = true;
+            this.lstAccessTypes.HorizontalScrollbar = true;
+            this.lstAccessTypes.Location = new System.Drawing.Point(661, 88);
+            this.lstAccessTypes.MultiColumn = true;
+            this.lstAccessTypes.Name = "lstAccessTypes";
+            this.lstAccessTypes.Size = new System.Drawing.Size(250, 109);
+            this.lstAccessTypes.TabIndex = 61;
+            // 
+            // cboAccessTypeFilter
+            // 
+            this.cboAccessTypeFilter.Location = new System.Drawing.Point(661, 40);
+            this.cboAccessTypeFilter.Name = "cboAccessTypeFilter";
+            this.cboAccessTypeFilter.Size = new System.Drawing.Size(250, 21);
+            this.cboAccessTypeFilter.TabIndex = 60;
+            this.cboAccessTypeFilter.Text = "cboAccessTypeFilter";
+            this.cboAccessTypeFilter.SelectionChangeCommitted += new System.EventHandler(this.cboAccessTypeFilter_SelectionChangeCommitted);
+            // 
+            // grpDayOfWeek
+            // 
+            this.grpDayOfWeek.Controls.Add(this.chkSun);
+            this.grpDayOfWeek.Controls.Add(this.chkSat);
+            this.grpDayOfWeek.Controls.Add(this.chkFri);
+            this.grpDayOfWeek.Controls.Add(this.chkThu);
+            this.grpDayOfWeek.Controls.Add(this.chkWed);
+            this.grpDayOfWeek.Controls.Add(this.chkTue);
+            this.grpDayOfWeek.Controls.Add(this.chkMon);
+            this.grpDayOfWeek.Location = new System.Drawing.Point(311, 94);
+            this.grpDayOfWeek.Name = "grpDayOfWeek";
+            this.grpDayOfWeek.Size = new System.Drawing.Size(240, 101);
+            this.grpDayOfWeek.TabIndex = 59;
+            this.grpDayOfWeek.TabStop = false;
+            this.grpDayOfWeek.Text = "Day of the Week";
+            // 
+            // chkSun
+            // 
+            this.chkSun.Location = new System.Drawing.Point(176, 64);
+            this.chkSun.Name = "chkSun";
+            this.chkSun.Size = new System.Drawing.Size(48, 16);
+            this.chkSun.TabIndex = 6;
+            this.chkSun.Text = "Sun";
+            // 
+            // chkSat
+            // 
+            this.chkSat.Location = new System.Drawing.Point(128, 64);
+            this.chkSat.Name = "chkSat";
+            this.chkSat.Size = new System.Drawing.Size(48, 16);
+            this.chkSat.TabIndex = 5;
+            this.chkSat.Text = "Sat";
+            // 
+            // chkFri
+            // 
+            this.chkFri.Location = new System.Drawing.Point(72, 64);
+            this.chkFri.Name = "chkFri";
+            this.chkFri.Size = new System.Drawing.Size(48, 16);
+            this.chkFri.TabIndex = 4;
+            this.chkFri.Text = "Fri";
+            // 
+            // chkThu
+            // 
+            this.chkThu.Location = new System.Drawing.Point(16, 64);
+            this.chkThu.Name = "chkThu";
+            this.chkThu.Size = new System.Drawing.Size(48, 16);
+            this.chkThu.TabIndex = 3;
+            this.chkThu.Text = "Thu";
+            // 
+            // chkWed
+            // 
+            this.chkWed.Location = new System.Drawing.Point(128, 32);
+            this.chkWed.Name = "chkWed";
+            this.chkWed.Size = new System.Drawing.Size(48, 16);
+            this.chkWed.TabIndex = 2;
+            this.chkWed.Text = "Wed";
+            // 
+            // chkTue
+            // 
+            this.chkTue.Location = new System.Drawing.Point(72, 32);
+            this.chkTue.Name = "chkTue";
+            this.chkTue.Size = new System.Drawing.Size(48, 16);
+            this.chkTue.TabIndex = 1;
+            this.chkTue.Text = "Tue";
+            // 
+            // chkMon
+            // 
+            this.chkMon.Location = new System.Drawing.Point(16, 32);
+            this.chkMon.Name = "chkMon";
+            this.chkMon.Size = new System.Drawing.Size(48, 16);
+            this.chkMon.TabIndex = 0;
+            this.chkMon.Text = "Mon";
+            // 
+            // grpTimeOfDay
+            // 
+            this.grpTimeOfDay.Controls.Add(this.rdoBoth);
+            this.grpTimeOfDay.Controls.Add(this.rdoPM);
+            this.grpTimeOfDay.Controls.Add(this.rdoAM);
+            this.grpTimeOfDay.Location = new System.Drawing.Point(311, 32);
+            this.grpTimeOfDay.Name = "grpTimeOfDay";
+            this.grpTimeOfDay.Size = new System.Drawing.Size(240, 48);
+            this.grpTimeOfDay.TabIndex = 58;
+            this.grpTimeOfDay.TabStop = false;
+            this.grpTimeOfDay.Text = "Time of Day";
+            // 
+            // rdoBoth
+            // 
+            this.rdoBoth.Checked = true;
+            this.rdoBoth.Location = new System.Drawing.Point(176, 24);
+            this.rdoBoth.Name = "rdoBoth";
+            this.rdoBoth.Size = new System.Drawing.Size(48, 16);
+            this.rdoBoth.TabIndex = 2;
+            this.rdoBoth.TabStop = true;
+            this.rdoBoth.Text = "Both";
+            // 
+            // rdoPM
+            // 
+            this.rdoPM.Location = new System.Drawing.Point(96, 24);
+            this.rdoPM.Name = "rdoPM";
+            this.rdoPM.Size = new System.Drawing.Size(72, 16);
+            this.rdoPM.TabIndex = 1;
+            this.rdoPM.Text = "PM Only";
+            // 
+            // rdoAM
+            // 
+            this.rdoAM.Location = new System.Drawing.Point(16, 24);
+            this.rdoAM.Name = "rdoAM";
+            this.rdoAM.Size = new System.Drawing.Size(72, 16);
+            this.rdoAM.TabIndex = 0;
+            this.rdoAM.Text = "AM Only";
+            // 
+            // label1
+            // 
+            this.label1.Font = new System.Drawing.Font("Microsoft Sans Serif", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
+            this.label1.Location = new System.Drawing.Point(16, 24);
+            this.label1.Name = "label1";
+            this.label1.Size = new System.Drawing.Size(136, 16);
+            this.label1.TabIndex = 57;
+            this.label1.Text = "Date Range:";
+            // 
+            // calStartDate
+            // 
+            this.calStartDate.Location = new System.Drawing.Point(16, 40);
+            this.calStartDate.MaxSelectionCount = 62;
+            this.calStartDate.Name = "calStartDate";
+            this.calStartDate.TabIndex = 56;
+            // 
+            // groupBox2
+            // 
+            this.groupBox2.Controls.Add(this.grdResult);
+            this.groupBox2.Dock = System.Windows.Forms.DockStyle.Fill;
+            this.groupBox2.Location = new System.Drawing.Point(0, 208);
+            this.groupBox2.Name = "groupBox2";
+            this.groupBox2.Size = new System.Drawing.Size(923, 189);
+            this.groupBox2.TabIndex = 57;
+            this.groupBox2.TabStop = false;
+            this.groupBox2.Text = "Search Result";
+            // 
+            // grdResult
+            // 
+            this.grdResult.CaptionVisible = false;
+            this.grdResult.DataMember = "";
+            this.grdResult.Dock = System.Windows.Forms.DockStyle.Fill;
+            this.grdResult.HeaderForeColor = System.Drawing.SystemColors.ControlText;
+            this.grdResult.Location = new System.Drawing.Point(3, 16);
+            this.grdResult.Name = "grdResult";
+            this.grdResult.ReadOnly = true;
+            this.grdResult.Size = new System.Drawing.Size(917, 170);
+            this.grdResult.TabIndex = 0;
+            this.grdResult.DoubleClick += new System.EventHandler(this.grdResult_DoubleClick);
+            this.grdResult.CurrentCellChanged += new System.EventHandler(this.grdResult_CurrentCellChanged);
+            // 
+            // DApptSearch
+            // 
+            this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
+            this.CancelButton = this.cmdCancel;
+            this.ClientSize = new System.Drawing.Size(923, 501);
+            this.Controls.Add(this.groupBox2);
+            this.Controls.Add(this.groupBox1);
+            this.Controls.Add(this.pnlDescription);
+            this.Controls.Add(this.panel1);
+            this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedDialog;
+            this.Name = "DApptSearch";
+            this.Text = "Find Clinic Availability";
+            this.panel1.ResumeLayout(false);
+            this.pnlDescription.ResumeLayout(false);
+            this.grpDescription.ResumeLayout(false);
+            this.groupBox1.ResumeLayout(false);
+            this.grpDayOfWeek.ResumeLayout(false);
+            this.grpTimeOfDay.ResumeLayout(false);
+            this.groupBox2.ResumeLayout(false);
+            ((System.ComponentModel.ISupportInitialize)(this.grdResult)).EndInit();
+            this.ResumeLayout(false);
 
 		}
Index: /Scheduling/trunk/cs/bsdx0200GUISourceCode/DApptSearch.resx
===================================================================
--- /Scheduling/trunk/cs/bsdx0200GUISourceCode/DApptSearch.resx	(revision 907)
+++ /Scheduling/trunk/cs/bsdx0200GUISourceCode/DApptSearch.resx	(revision 908)
@@ -4,5 +4,5 @@
     Microsoft ResX Schema 
     
-    Version 1.3
+    Version 2.0
     
     The primary goals of this format is to allow a simple XML format 
@@ -15,14 +15,15 @@
     ... ado.net/XML headers & schema ...
     <resheader name="resmimetype">text/microsoft-resx</resheader>
-    <resheader name="version">1.3</resheader>
+    <resheader name="version">2.0</resheader>
     <resheader name="reader">System.Resources.ResXResourceReader, System.Windows.Forms, ...</resheader>
     <resheader name="writer">System.Resources.ResXResourceWriter, System.Windows.Forms, ...</resheader>
-    <data name="Name1">this is my long string</data>
+    <data name="Name1"><value>this is my long string</value><comment>this is a comment</comment></data>
     <data name="Color1" type="System.Drawing.Color, System.Drawing">Blue</data>
     <data name="Bitmap1" mimetype="application/x-microsoft.net.object.binary.base64">
-        [base64 mime encoded serialized .NET Framework object]
+        <value>[base64 mime encoded serialized .NET Framework object]</value>
     </data>
     <data name="Icon1" type="System.Drawing.Icon, System.Drawing" mimetype="application/x-microsoft.net.object.bytearray.base64">
-        [base64 mime encoded string representing a byte array form of the .NET Framework object]
+        <value>[base64 mime encoded string representing a byte array form of the .NET Framework object]</value>
+        <comment>This is a comment</comment>
     </data>
                 
@@ -36,5 +37,5 @@
     mimetype set.
     
-    The mimetype is used forserialized objects, and tells the 
+    The mimetype is used for serialized objects, and tells the 
     ResXResourceReader how to depersist the object. This is currently not 
     extensible. For a given mimetype the value must be set accordingly:
@@ -46,5 +47,5 @@
     mimetype: application/x-microsoft.net.object.binary.base64
     value   : The object must be serialized with 
-            : System.Serialization.Formatters.Binary.BinaryFormatter
+            : System.Runtime.Serialization.Formatters.Binary.BinaryFormatter
             : and then encoded with base64 encoding.
     
@@ -60,7 +61,25 @@
     -->
   <xsd:schema id="root" xmlns="" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msdata="urn:schemas-microsoft-com:xml-msdata">
+    <xsd:import namespace="http://www.w3.org/XML/1998/namespace" />
     <xsd:element name="root" msdata:IsDataSet="true">
       <xsd:complexType>
         <xsd:choice maxOccurs="unbounded">
+          <xsd:element name="metadata">
+            <xsd:complexType>
+              <xsd:sequence>
+                <xsd:element name="value" type="xsd:string" minOccurs="0" />
+              </xsd:sequence>
+              <xsd:attribute name="name" use="required" type="xsd:string" />
+              <xsd:attribute name="type" type="xsd:string" />
+              <xsd:attribute name="mimetype" type="xsd:string" />
+              <xsd:attribute ref="xml:space" />
+            </xsd:complexType>
+          </xsd:element>
+          <xsd:element name="assembly">
+            <xsd:complexType>
+              <xsd:attribute name="alias" type="xsd:string" />
+              <xsd:attribute name="name" type="xsd:string" />
+            </xsd:complexType>
+          </xsd:element>
           <xsd:element name="data">
             <xsd:complexType>
@@ -69,7 +88,8 @@
                 <xsd:element name="comment" type="xsd:string" minOccurs="0" msdata:Ordinal="2" />
               </xsd:sequence>
-              <xsd:attribute name="name" type="xsd:string" msdata:Ordinal="1" />
+              <xsd:attribute name="name" type="xsd:string" use="required" msdata:Ordinal="1" />
               <xsd:attribute name="type" type="xsd:string" msdata:Ordinal="3" />
               <xsd:attribute name="mimetype" type="xsd:string" msdata:Ordinal="4" />
+              <xsd:attribute ref="xml:space" />
             </xsd:complexType>
           </xsd:element>
@@ -90,356 +110,11 @@
   </resheader>
   <resheader name="version">
-    <value>1.3</value>
+    <value>2.0</value>
   </resheader>
   <resheader name="reader">
-    <value>System.Resources.ResXResourceReader, System.Windows.Forms, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089</value>
+    <value>System.Resources.ResXResourceReader, System.Windows.Forms, Version=2.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089</value>
   </resheader>
   <resheader name="writer">
-    <value>System.Resources.ResXResourceWriter, System.Windows.Forms, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089</value>
+    <value>System.Resources.ResXResourceWriter, System.Windows.Forms, Version=2.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089</value>
   </resheader>
-  <data name="panel1.Locked" type="System.Boolean, mscorlib, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>False</value>
-  </data>
-  <data name="panel1.SnapToGrid" type="System.Boolean, mscorlib, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>True</value>
-  </data>
-  <data name="panel1.DefaultModifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="panel1.GridSize" type="System.Drawing.Size, System.Drawing, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a">
-    <value>8, 8</value>
-  </data>
-  <data name="panel1.DrawGrid" type="System.Boolean, mscorlib, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>True</value>
-  </data>
-  <data name="panel1.Modifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="cmdSearch.Locked" type="System.Boolean, mscorlib, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>False</value>
-  </data>
-  <data name="cmdSearch.DefaultModifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="cmdSearch.Modifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="cmdCancel.Locked" type="System.Boolean, mscorlib, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>False</value>
-  </data>
-  <data name="cmdCancel.DefaultModifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="cmdCancel.Modifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="cmdOK.Locked" type="System.Boolean, mscorlib, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>False</value>
-  </data>
-  <data name="cmdOK.DefaultModifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="cmdOK.Modifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="pnlDescription.Locked" type="System.Boolean, mscorlib, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>False</value>
-  </data>
-  <data name="pnlDescription.SnapToGrid" type="System.Boolean, mscorlib, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>True</value>
-  </data>
-  <data name="pnlDescription.DefaultModifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="pnlDescription.GridSize" type="System.Drawing.Size, System.Drawing, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a">
-    <value>8, 8</value>
-  </data>
-  <data name="pnlDescription.DrawGrid" type="System.Boolean, mscorlib, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>True</value>
-  </data>
-  <data name="pnlDescription.Modifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="grpDescription.DefaultModifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="grpDescription.GridSize" type="System.Drawing.Size, System.Drawing, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a">
-    <value>8, 8</value>
-  </data>
-  <data name="grpDescription.SnapToGrid" type="System.Boolean, mscorlib, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>True</value>
-  </data>
-  <data name="grpDescription.Locked" type="System.Boolean, mscorlib, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>False</value>
-  </data>
-  <data name="grpDescription.DrawGrid" type="System.Boolean, mscorlib, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>True</value>
-  </data>
-  <data name="grpDescription.Modifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="lblDescription.Locked" type="System.Boolean, mscorlib, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>False</value>
-  </data>
-  <data name="lblDescription.DefaultModifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="lblDescription.Modifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="groupBox1.DefaultModifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="groupBox1.GridSize" type="System.Drawing.Size, System.Drawing, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a">
-    <value>8, 8</value>
-  </data>
-  <data name="groupBox1.SnapToGrid" type="System.Boolean, mscorlib, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>True</value>
-  </data>
-  <data name="groupBox1.Locked" type="System.Boolean, mscorlib, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>False</value>
-  </data>
-  <data name="groupBox1.DrawGrid" type="System.Boolean, mscorlib, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>True</value>
-  </data>
-  <data name="groupBox1.Modifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="label3.Locked" type="System.Boolean, mscorlib, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>False</value>
-  </data>
-  <data name="label3.DefaultModifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="label3.Modifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="label2.Locked" type="System.Boolean, mscorlib, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>False</value>
-  </data>
-  <data name="label2.DefaultModifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="label2.Modifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="lstAccessTypes.DefaultModifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="lstAccessTypes.Locked" type="System.Boolean, mscorlib, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>False</value>
-  </data>
-  <data name="lstAccessTypes.Modifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="cboAccessTypeFilter.DefaultModifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="cboAccessTypeFilter.Locked" type="System.Boolean, mscorlib, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>False</value>
-  </data>
-  <data name="cboAccessTypeFilter.Modifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="grpDayOfWeek.DefaultModifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="grpDayOfWeek.GridSize" type="System.Drawing.Size, System.Drawing, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a">
-    <value>8, 8</value>
-  </data>
-  <data name="grpDayOfWeek.SnapToGrid" type="System.Boolean, mscorlib, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>True</value>
-  </data>
-  <data name="grpDayOfWeek.Locked" type="System.Boolean, mscorlib, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>False</value>
-  </data>
-  <data name="grpDayOfWeek.DrawGrid" type="System.Boolean, mscorlib, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>True</value>
-  </data>
-  <data name="grpDayOfWeek.Modifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="chkSun.Locked" type="System.Boolean, mscorlib, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>False</value>
-  </data>
-  <data name="chkSun.DefaultModifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="chkSun.Modifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="chkSat.Locked" type="System.Boolean, mscorlib, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>False</value>
-  </data>
-  <data name="chkSat.DefaultModifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="chkSat.Modifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="chkFri.Locked" type="System.Boolean, mscorlib, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>False</value>
-  </data>
-  <data name="chkFri.DefaultModifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="chkFri.Modifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="chkThu.Locked" type="System.Boolean, mscorlib, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>False</value>
-  </data>
-  <data name="chkThu.DefaultModifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="chkThu.Modifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="chkWed.Locked" type="System.Boolean, mscorlib, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>False</value>
-  </data>
-  <data name="chkWed.DefaultModifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="chkWed.Modifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="chkTue.Locked" type="System.Boolean, mscorlib, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>False</value>
-  </data>
-  <data name="chkTue.DefaultModifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="chkTue.Modifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="chkMon.Locked" type="System.Boolean, mscorlib, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>False</value>
-  </data>
-  <data name="chkMon.DefaultModifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="chkMon.Modifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="grpTimeOfDay.DefaultModifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="grpTimeOfDay.GridSize" type="System.Drawing.Size, System.Drawing, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a">
-    <value>8, 8</value>
-  </data>
-  <data name="grpTimeOfDay.SnapToGrid" type="System.Boolean, mscorlib, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>True</value>
-  </data>
-  <data name="grpTimeOfDay.Locked" type="System.Boolean, mscorlib, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>False</value>
-  </data>
-  <data name="grpTimeOfDay.DrawGrid" type="System.Boolean, mscorlib, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>True</value>
-  </data>
-  <data name="grpTimeOfDay.Modifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="rdoBoth.Locked" type="System.Boolean, mscorlib, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>False</value>
-  </data>
-  <data name="rdoBoth.DefaultModifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="rdoBoth.Modifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="rdoPM.Locked" type="System.Boolean, mscorlib, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>False</value>
-  </data>
-  <data name="rdoPM.DefaultModifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="rdoPM.Modifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="rdoAM.Locked" type="System.Boolean, mscorlib, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>False</value>
-  </data>
-  <data name="rdoAM.DefaultModifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="rdoAM.Modifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="label1.Locked" type="System.Boolean, mscorlib, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>False</value>
-  </data>
-  <data name="label1.DefaultModifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="label1.Modifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="calStartDate.DefaultModifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="calStartDate.Modifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="calStartDate.Locked" type="System.Boolean, mscorlib, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>False</value>
-  </data>
-  <data name="groupBox2.DefaultModifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="groupBox2.GridSize" type="System.Drawing.Size, System.Drawing, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a">
-    <value>8, 8</value>
-  </data>
-  <data name="groupBox2.SnapToGrid" type="System.Boolean, mscorlib, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>True</value>
-  </data>
-  <data name="groupBox2.Locked" type="System.Boolean, mscorlib, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>False</value>
-  </data>
-  <data name="groupBox2.DrawGrid" type="System.Boolean, mscorlib, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>True</value>
-  </data>
-  <data name="groupBox2.Modifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="grdResult.Locked" type="System.Boolean, mscorlib, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>False</value>
-  </data>
-  <data name="grdResult.Modifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="grdResult.DefaultModifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
-  <data name="$this.Locked" type="System.Boolean, mscorlib, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>False</value>
-  </data>
-  <data name="$this.Language" type="System.Globalization.CultureInfo, mscorlib, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>(Default)</value>
-  </data>
-  <data name="$this.TrayLargeIcon" type="System.Boolean, mscorlib, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>False</value>
-  </data>
-  <data name="$this.Localizable" type="System.Boolean, mscorlib, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>False</value>
-  </data>
-  <data name="$this.GridSize" type="System.Drawing.Size, System.Drawing, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b03f5f7f11d50a3a">
-    <value>8, 8</value>
-  </data>
-  <data name="$this.DrawGrid" type="System.Boolean, mscorlib, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>True</value>
-  </data>
-  <data name="$this.TrayHeight" type="System.Int32, mscorlib, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>80</value>
-  </data>
-  <data name="$this.Name">
-    <value>DApptSearch</value>
-  </data>
-  <data name="$this.SnapToGrid" type="System.Boolean, mscorlib, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>True</value>
-  </data>
-  <data name="$this.DefaultModifiers" type="System.CodeDom.MemberAttributes, System, Version=1.0.5000.0, Culture=neutral, PublicKeyToken=b77a5c561934e089">
-    <value>Private</value>
-  </data>
 </root>

Index: /Scheduling/trunk/cs/bsdx0200GUISourceCode/CGDocument.cs
===================================================================
--- /Scheduling/trunk/cs/bsdx0200GUISourceCode/CGDocument.cs	(revision 907)
+++ /Scheduling/trunk/cs/bsdx0200GUISourceCode/CGDocument.cs	(revision 908)
@@ -668,6 +668,6 @@
 			DateTime OldStartDay = m_dStartDate;
 			DateTime OldEndDay = m_dEndDate;
-            // Week start based on machine locale
-            int nStartWeekDay = (int)System.Globalization.CultureInfo.CurrentCulture.DateTimeFormat.FirstDayOfWeek;
+            // Week start based on thread locale
+            int nStartWeekDay = (int)System.Threading.Thread.CurrentThread.CurrentCulture.DateTimeFormat.FirstDayOfWeek;
             int nWeekDay = (int) SelectedDate.DayOfWeek; //0 == Sunday
 